import cv2

def sketch(image):

  gray_image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
  cv2.imshow("President Trump", gray_image)

  inverted_image = 255 - gray_image
  blurred = cv2.GaussianBlur(inverted_image, ksize=(21, 21),sigmaX=0, sigmaY=0)

  inverted_blurred = 255 - blurred
  pencil_sketch = cv2.divide(gray_image, inverted_blurred, scale=256.0)
  cv2.imshow("Sketch", pencil_sketch)

  cv2.imshow("pencil sketch", pencil_sketch)
  cv2.imwrite("trump.png",pencil_sketch)
  cv2.waitKey(0)




from setuptools import setup

setup(
    name='pencilpy',
    version='0.2.0',    
    description='Get pencil sketches from image',
    url='https://github.com/dingus45191/pencil-cartoon',
    author='MOhammed Mubashir Hasan',
    author_email='mubashirhasan716@gmail.com',
    license='BSD 2-clause',
    packages=['pencilpy'],
    install_requires=['opencv-python',
                      'numpy',                     
                      ],

    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',  
        'Operating System :: POSIX :: Linux',        
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)